
ids = None
ciudades = None
infoUser = ''
cookieFile = '/tmp/.cookies.txt'
telegramFile = '/tmp/.telegram.txt'
urlCiudad = 'view=city&cityId='
urlIsla = 'view=island&islandId='
prompt = ' >>  '
tipoDeBien = ['Madera', 'Vino', 'Marmol', 'Cristal', 'Azufre']
